@@ -4,7 +4,7 @@ package urpm::select;
 
 use strict;
 use urpm::msg;
-use urpm::util qw(any formatList intersection member min partition uniq);
+use urpm::util;
 use urpm::sys;
 use URPM;
 
@@ -178,12 +178,14 @@ sub _search_packages {
 	    if (!$options{fuzzy}) {
 		if ($pack eq $v) {
 		    $exact{$v} = $id;
+		    next;
 		} elsif ($pack_a eq $v) {
 		    push @{$exact_a{$v}}, $id;
+		    next;
 		} elsif ($pack_ra eq $v || $options{src} && $pack_name eq $v) {
 		    push @{$exact_ra{$v}}, $id;
+		    next;
 		}
-		next;
 	    }
 	    if ($pack =~ /$qv/) {
 		next if member($pack, @found);
@@ -220,7 +222,7 @@ sub _search_packages {
 		$urpm->{error}(N("No package named %s", $v));
 		values(%l) != 0 and $urpm->{error}(
 		    N("The following packages contain %s: %s",
-			$v, formatList(4, sort { $a cmp $b } keys %l)) . "\n" . 
+			$v, urpm::util::formatList(4, sort { $a cmp $b } keys %l)) . "\n" . 
 		    N("You should use \"-a\" to use all of them")
 		);
 		$result = 0;
@@ -353,7 +355,6 @@ sub resolve_dependencies {
 		$need_restart = _resolve_priority_upgrades($urpm, $db, $state, $state->{selected}, \@l, %options);
 	    }
 	}
-	$urpm->{options}{'split-length'} = 0 if $need_restart;
     }
     $need_restart;
 }
@@ -719,7 +720,7 @@ sub translate_why_removed_one {
 }
 
 sub _libdb_version { $_[0] =~ /libdb-(\S+)\.so/ ? version->new("v$1") : () }
-sub _rpm_version() { `rpm --version` =~ /version ([0-9.]+)(?:-beta.*)?$/ ? version->new("v$1") : () }
+sub _rpm_version() { `rpm --version` =~ /version ([0-9.]+)$/ ? version->new("v$1") : () }
 
 sub should_we_migrate_back_rpmdb_db_version {
     my ($urpm, $state) = @_;
